# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import esmlouvy_connector
from esmlouvy_connector.api.attachments_api import AttachmentsApi  # noqa: E501
from esmlouvy_connector.rest import ApiException


class TestAttachmentsApi(unittest.TestCase):
    """AttachmentsApi unit test stubs"""

    def setUp(self):
        self.api = AttachmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_attachment(self):
        """Test case for delete_attachment

        odstraní přílohu i s metadaty  # noqa: E501
        """
        pass

    def test_get_attachment(self):
        """Test case for get_attachment

        vrací soubor přílohy  # noqa: E501
        """
        pass

    def test_get_attachment_list(self):
        """Test case for get_attachment_list

        získá seznam příloh  # noqa: E501
        """
        pass

    def test_get_attachment_list_container(self):
        """Test case for get_attachment_list_container

        vrací seznam příloh v kontejneru  # noqa: E501
        """
        pass

    def test_get_attachment_list_document(self):
        """Test case for get_attachment_list_document

        vrací seznam příloh v dokumentu  # noqa: E501
        """
        pass

    def test_get_attachment_metadata(self):
        """Test case for get_attachment_metadata

        vrací metadata přílohy  # noqa: E501
        """
        pass

    def test_post_attachment(self):
        """Test case for post_attachment

        uploaduje novou přílohu (Crud)  # noqa: E501
        """
        pass

    def test_put_attachment(self):
        """Test case for put_attachment

        aktualizuje metadata přílohy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentEntryList(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key': 'str',
        'search': 'str',
        'category': 'str',
        'parent_id': 'str',
        'parent_uuid': 'str',
        'start': 'int',
        'page_size': 'int',
        'page': 'int',
        'count': 'int',
        'entries': 'list[DocumentEntry]'
    }

    attribute_map = {
        'key': 'key',
        'search': 'search',
        'category': 'category',
        'parent_id': 'parent_id',
        'parent_uuid': 'parent_uuid',
        'start': 'start',
        'page_size': 'page_size',
        'page': 'page',
        'count': 'count',
        'entries': 'entries'
    }

    def __init__(self, key=None, search=None, category=None, parent_id=None, parent_uuid=None, start=None, page_size=None, page=None, count=None, entries=None):  # noqa: E501
        """DocumentEntryList - a model defined in Swagger"""  # noqa: E501
        self._key = None
        self._search = None
        self._category = None
        self._parent_id = None
        self._parent_uuid = None
        self._start = None
        self._page_size = None
        self._page = None
        self._count = None
        self._entries = None
        self.discriminator = None
        if key is not None:
            self.key = key
        if search is not None:
            self.search = search
        if category is not None:
            self.category = category
        if parent_id is not None:
            self.parent_id = parent_id
        if parent_uuid is not None:
            self.parent_uuid = parent_uuid
        if start is not None:
            self.start = start
        if page_size is not None:
            self.page_size = page_size
        if page is not None:
            self.page = page
        if count is not None:
            self.count = count
        if entries is not None:
            self.entries = entries

    @property
    def key(self):
        """Gets the key of this DocumentEntryList.  # noqa: E501

        Může být identifikátor nebo jiný textový klíč (např. čj.)  # noqa: E501

        :return: The key of this DocumentEntryList.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this DocumentEntryList.

        Může být identifikátor nebo jiný textový klíč (např. čj.)  # noqa: E501

        :param key: The key of this DocumentEntryList.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def search(self):
        """Gets the search of this DocumentEntryList.  # noqa: E501

        Text pro fulltextové vyhledávání  # noqa: E501

        :return: The search of this DocumentEntryList.  # noqa: E501
        :rtype: str
        """
        return self._search

    @search.setter
    def search(self, search):
        """Sets the search of this DocumentEntryList.

        Text pro fulltextové vyhledávání  # noqa: E501

        :param search: The search of this DocumentEntryList.  # noqa: E501
        :type: str
        """

        self._search = search

    @property
    def category(self):
        """Gets the category of this DocumentEntryList.  # noqa: E501

        Vrácená kategorie  # noqa: E501

        :return: The category of this DocumentEntryList.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this DocumentEntryList.

        Vrácená kategorie  # noqa: E501

        :param category: The category of this DocumentEntryList.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def parent_id(self):
        """Gets the parent_id of this DocumentEntryList.  # noqa: E501

        Identifikátor rodičovského dokumentu  # noqa: E501

        :return: The parent_id of this DocumentEntryList.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this DocumentEntryList.

        Identifikátor rodičovského dokumentu  # noqa: E501

        :param parent_id: The parent_id of this DocumentEntryList.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def parent_uuid(self):
        """Gets the parent_uuid of this DocumentEntryList.  # noqa: E501

        UUID identifikátor rodičovského dokumentu  # noqa: E501

        :return: The parent_uuid of this DocumentEntryList.  # noqa: E501
        :rtype: str
        """
        return self._parent_uuid

    @parent_uuid.setter
    def parent_uuid(self, parent_uuid):
        """Sets the parent_uuid of this DocumentEntryList.

        UUID identifikátor rodičovského dokumentu  # noqa: E501

        :param parent_uuid: The parent_uuid of this DocumentEntryList.  # noqa: E501
        :type: str
        """

        self._parent_uuid = parent_uuid

    @property
    def start(self):
        """Gets the start of this DocumentEntryList.  # noqa: E501

        Počáteční dokument na stránce  # noqa: E501

        :return: The start of this DocumentEntryList.  # noqa: E501
        :rtype: int
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this DocumentEntryList.

        Počáteční dokument na stránce  # noqa: E501

        :param start: The start of this DocumentEntryList.  # noqa: E501
        :type: int
        """

        self._start = start

    @property
    def page_size(self):
        """Gets the page_size of this DocumentEntryList.  # noqa: E501

        Velikost stránky  # noqa: E501

        :return: The page_size of this DocumentEntryList.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this DocumentEntryList.

        Velikost stránky  # noqa: E501

        :param page_size: The page_size of this DocumentEntryList.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def page(self):
        """Gets the page of this DocumentEntryList.  # noqa: E501

        Požadovaná stránka  # noqa: E501

        :return: The page of this DocumentEntryList.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this DocumentEntryList.

        Požadovaná stránka  # noqa: E501

        :param page: The page of this DocumentEntryList.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def count(self):
        """Gets the count of this DocumentEntryList.  # noqa: E501

        celkový počet vrácených položek  # noqa: E501

        :return: The count of this DocumentEntryList.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this DocumentEntryList.

        celkový počet vrácených položek  # noqa: E501

        :param count: The count of this DocumentEntryList.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def entries(self):
        """Gets the entries of this DocumentEntryList.  # noqa: E501


        :return: The entries of this DocumentEntryList.  # noqa: E501
        :rtype: list[DocumentEntry]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """Sets the entries of this DocumentEntryList.


        :param entries: The entries of this DocumentEntryList.  # noqa: E501
        :type: list[DocumentEntry]
        """

        self._entries = entries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentEntryList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentEntryList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import esmlouvy_connector
from esmlouvy_connector.models.document_workflow import DocumentWorkflow  # noqa: E501
from esmlouvy_connector.rest import ApiException


class TestDocumentWorkflow(unittest.TestCase):
    """DocumentWorkflow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDocumentWorkflow(self):
        """Test DocumentWorkflow"""
        # FIXME: construct object with mandatory attributes with example values
        # model = esmlouvy_connector.models.document_workflow.DocumentWorkflow()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from esmlouvy_connector.api_client import ApiClient


class AttachmentsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_attachment(self, identifier, **kwargs):  # noqa: E501
        """odstraní přílohu i s metadaty  # noqa: E501

        Odstraní soubor dokumentové přílohy i s metadatovým kontejnerem  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_attachment(identifier, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str identifier: Identifikátor uuid přílohy (required)
        :param str storage: Replica ID storage application
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude operace provedena
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_attachment_with_http_info(identifier, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_attachment_with_http_info(identifier, **kwargs)  # noqa: E501
            return data

    def delete_attachment_with_http_info(self, identifier, **kwargs):  # noqa: E501
        """odstraní přílohu i s metadaty  # noqa: E501

        Odstraní soubor dokumentové přílohy i s metadatovým kontejnerem  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_attachment_with_http_info(identifier, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str identifier: Identifikátor uuid přílohy (required)
        :param str storage: Replica ID storage application
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude operace provedena
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['identifier', 'storage', 'author']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_attachment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'identifier' is set
        if ('identifier' not in params or
                params['identifier'] is None):
            raise ValueError("Missing the required parameter `identifier` when calling `delete_attachment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'identifier' in params:
            path_params['identifier'] = params['identifier']  # noqa: E501

        query_params = []
        if 'storage' in params:
            query_params.append(('storage', params['storage']))  # noqa: E501
        if 'author' in params:
            query_params.append(('author', params['author']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/attachment/{identifier}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attachment(self, identifier, **kwargs):  # noqa: E501
        """vrací soubor přílohy  # noqa: E501

        Vrátí soubor dokumentové přílohy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment(identifier, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str identifier: Identifikátor uuid přílohy (required)
        :param str storage: Replica ID storage application
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude dokument vrácen
        :param str reader: Autorizace podle čtenáře. Pokud je jméno mezi čtenáři, bude dokument vrácen
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_attachment_with_http_info(identifier, **kwargs)  # noqa: E501
        else:
            (data) = self.get_attachment_with_http_info(identifier, **kwargs)  # noqa: E501
            return data

    def get_attachment_with_http_info(self, identifier, **kwargs):  # noqa: E501
        """vrací soubor přílohy  # noqa: E501

        Vrátí soubor dokumentové přílohy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_with_http_info(identifier, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str identifier: Identifikátor uuid přílohy (required)
        :param str storage: Replica ID storage application
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude dokument vrácen
        :param str reader: Autorizace podle čtenáře. Pokud je jméno mezi čtenáři, bude dokument vrácen
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['identifier', 'storage', 'author', 'reader']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attachment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'identifier' is set
        if ('identifier' not in params or
                params['identifier'] is None):
            raise ValueError("Missing the required parameter `identifier` when calling `get_attachment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'identifier' in params:
            path_params['identifier'] = params['identifier']  # noqa: E501

        query_params = []
        if 'storage' in params:
            query_params.append(('storage', params['storage']))  # noqa: E501
        if 'author' in params:
            query_params.append(('author', params['author']))  # noqa: E501
        if 'reader' in params:
            query_params.append(('reader', params['reader']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/*', 'text/*', 'image/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/attachment/download/{identifier}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attachment_list(self, **kwargs):  # noqa: E501
        """získá seznam příloh  # noqa: E501

        Vrátí seznam příloh odpovídající klíči nebo fulltextovému dotazu  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: Vyhledávací klíčové slovo.
        :param str search: Textové položky pro fulltextové vyhledávání. Lze použít syntax fulltextového vyhledávání Domino - viz nápověda Domino  Při použití vyhledávání podle klíčového slova a fulltextu, je parametr key ignorován. 
        :param str creator: Tvůrce přílohy
        :param list[str] storage: Prohledávaná úložiště
        :param str sortcolumn: Třídit podle sloupce. Vrátí položky setříděné podle sloupce. Pokus sloupec není v návrhu tříděn nebo neexistuje, nemá tento parametr žádný efekt.
        :param str sortorder: Pořadí řazení. Může nabývat hodnot  \"ascending\" nebo \"descending\". Patří k parametru  \"sortcolumn\". 
        :param int start: První dokument na stránce
        :param int page_size: Velikost stránky při stránkovaném výstupu
        :param int page: Číslo stránky výstupu
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude dokument vrácen
        :param str reader: Autorizace podle čtenáře. Pokud je jméno mezi čtenáři, bude dokument vrácen
        :return: DocumentAttachmentList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_attachment_list_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_attachment_list_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_attachment_list_with_http_info(self, **kwargs):  # noqa: E501
        """získá seznam příloh  # noqa: E501

        Vrátí seznam příloh odpovídající klíči nebo fulltextovému dotazu  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: Vyhledávací klíčové slovo.
        :param str search: Textové položky pro fulltextové vyhledávání. Lze použít syntax fulltextového vyhledávání Domino - viz nápověda Domino  Při použití vyhledávání podle klíčového slova a fulltextu, je parametr key ignorován. 
        :param str creator: Tvůrce přílohy
        :param list[str] storage: Prohledávaná úložiště
        :param str sortcolumn: Třídit podle sloupce. Vrátí položky setříděné podle sloupce. Pokus sloupec není v návrhu tříděn nebo neexistuje, nemá tento parametr žádný efekt.
        :param str sortorder: Pořadí řazení. Může nabývat hodnot  \"ascending\" nebo \"descending\". Patří k parametru  \"sortcolumn\". 
        :param int start: První dokument na stránce
        :param int page_size: Velikost stránky při stránkovaném výstupu
        :param int page: Číslo stránky výstupu
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude dokument vrácen
        :param str reader: Autorizace podle čtenáře. Pokud je jméno mezi čtenáři, bude dokument vrácen
        :return: DocumentAttachmentList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['key', 'search', 'creator', 'storage', 'sortcolumn', 'sortorder', 'start', 'page_size', 'page', 'author', 'reader']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attachment_list" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'key' in params:
            query_params.append(('key', params['key']))  # noqa: E501
        if 'search' in params:
            query_params.append(('search', params['search']))  # noqa: E501
        if 'creator' in params:
            query_params.append(('creator', params['creator']))  # noqa: E501
        if 'storage' in params:
            query_params.append(('storage', params['storage']))  # noqa: E501
            collection_formats['storage'] = 'multi'  # noqa: E501
        if 'sortcolumn' in params:
            query_params.append(('sortcolumn', params['sortcolumn']))  # noqa: E501
        if 'sortorder' in params:
            query_params.append(('sortorder', params['sortorder']))  # noqa: E501
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('page_size', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'author' in params:
            query_params.append(('author', params['author']))  # noqa: E501
        if 'reader' in params:
            query_params.append(('reader', params['reader']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/attachment', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DocumentAttachmentList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attachment_list_container(self, container, **kwargs):  # noqa: E501
        """vrací seznam příloh v kontejneru  # noqa: E501

        Vrátí seznam souborových příloh zařazených do kontejneru  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_list_container(container, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container: Identifikátor uuid kontejneru. Může být PID, UNID nebo uuid (required)
        :param list[str] storage: Prohledávaná úložiště
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude dokument vrácen
        :param str reader: Autorizace podle čtenáře. Pokud je jméno mezi čtenáři, bude dokument vrácen
        :return: DocumentAttachmentList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_attachment_list_container_with_http_info(container, **kwargs)  # noqa: E501
        else:
            (data) = self.get_attachment_list_container_with_http_info(container, **kwargs)  # noqa: E501
            return data

    def get_attachment_list_container_with_http_info(self, container, **kwargs):  # noqa: E501
        """vrací seznam příloh v kontejneru  # noqa: E501

        Vrátí seznam souborových příloh zařazených do kontejneru  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_list_container_with_http_info(container, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container: Identifikátor uuid kontejneru. Může být PID, UNID nebo uuid (required)
        :param list[str] storage: Prohledávaná úložiště
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude dokument vrácen
        :param str reader: Autorizace podle čtenáře. Pokud je jméno mezi čtenáři, bude dokument vrácen
        :return: DocumentAttachmentList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container', 'storage', 'author', 'reader']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attachment_list_container" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container' is set
        if ('container' not in params or
                params['container'] is None):
            raise ValueError("Missing the required parameter `container` when calling `get_attachment_list_container`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container' in params:
            path_params['container'] = params['container']  # noqa: E501

        query_params = []
        if 'storage' in params:
            query_params.append(('storage', params['storage']))  # noqa: E501
            collection_formats['storage'] = 'multi'  # noqa: E501
        if 'author' in params:
            query_params.append(('author', params['author']))  # noqa: E501
        if 'reader' in params:
            query_params.append(('reader', params['reader']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/atachment/container/{container}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DocumentAttachmentList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attachment_list_document(self, document, **kwargs):  # noqa: E501
        """vrací seznam příloh v dokumentu  # noqa: E501

        Vrátí seznam souborových příloh zařazených do kontejneru  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_list_document(document, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str document: Identifikátor uuid dokumentu. Může být PID, UNID nebo uuid (required)
        :param list[str] storage: Prohledávaná úložiště
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude dokument vrácen
        :param str reader: Autorizace podle čtenáře. Pokud je jméno mezi čtenáři, bude dokument vrácen
        :return: DocumentAttachmentList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_attachment_list_document_with_http_info(document, **kwargs)  # noqa: E501
        else:
            (data) = self.get_attachment_list_document_with_http_info(document, **kwargs)  # noqa: E501
            return data

    def get_attachment_list_document_with_http_info(self, document, **kwargs):  # noqa: E501
        """vrací seznam příloh v dokumentu  # noqa: E501

        Vrátí seznam souborových příloh zařazených do kontejneru  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_list_document_with_http_info(document, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str document: Identifikátor uuid dokumentu. Může být PID, UNID nebo uuid (required)
        :param list[str] storage: Prohledávaná úložiště
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude dokument vrácen
        :param str reader: Autorizace podle čtenáře. Pokud je jméno mezi čtenáři, bude dokument vrácen
        :return: DocumentAttachmentList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['document', 'storage', 'author', 'reader']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attachment_list_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'document' is set
        if ('document' not in params or
                params['document'] is None):
            raise ValueError("Missing the required parameter `document` when calling `get_attachment_list_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'document' in params:
            path_params['document'] = params['document']  # noqa: E501

        query_params = []
        if 'storage' in params:
            query_params.append(('storage', params['storage']))  # noqa: E501
            collection_formats['storage'] = 'multi'  # noqa: E501
        if 'author' in params:
            query_params.append(('author', params['author']))  # noqa: E501
        if 'reader' in params:
            query_params.append(('reader', params['reader']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/atachment/document/{document}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DocumentAttachmentList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attachment_metadata(self, identifier, **kwargs):  # noqa: E501
        """vrací metadata přílohy  # noqa: E501

        Vrátí metadata dokumentové přílohy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_metadata(identifier, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str identifier: Identifikátor uuid přílohy (required)
        :param str storage: Replica ID storage application
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude dokument vrácen
        :param str reader: Autorizace podle čtenáře. Pokud je jméno mezi čtenáři, bude dokument vrácen
        :return: DocumentAttachment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_attachment_metadata_with_http_info(identifier, **kwargs)  # noqa: E501
        else:
            (data) = self.get_attachment_metadata_with_http_info(identifier, **kwargs)  # noqa: E501
            return data

    def get_attachment_metadata_with_http_info(self, identifier, **kwargs):  # noqa: E501
        """vrací metadata přílohy  # noqa: E501

        Vrátí metadata dokumentové přílohy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_metadata_with_http_info(identifier, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str identifier: Identifikátor uuid přílohy (required)
        :param str storage: Replica ID storage application
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude dokument vrácen
        :param str reader: Autorizace podle čtenáře. Pokud je jméno mezi čtenáři, bude dokument vrácen
        :return: DocumentAttachment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['identifier', 'storage', 'author', 'reader']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attachment_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'identifier' is set
        if ('identifier' not in params or
                params['identifier'] is None):
            raise ValueError("Missing the required parameter `identifier` when calling `get_attachment_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'identifier' in params:
            path_params['identifier'] = params['identifier']  # noqa: E501

        query_params = []
        if 'storage' in params:
            query_params.append(('storage', params['storage']))  # noqa: E501
        if 'author' in params:
            query_params.append(('author', params['author']))  # noqa: E501
        if 'reader' in params:
            query_params.append(('reader', params['reader']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/attachment/{identifier}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DocumentAttachment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_attachment(self, name, **kwargs):  # noqa: E501
        """uploaduje novou přílohu (Crud)  # noqa: E501

        Uploaduje novou souborovou přílohu dokumentu  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_attachment(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: Attachment name for display (required)
        :param Object body: binární soubor base64
        :param str storage: Replica ID storage application
        :param str title: Attachment title for display
        :param str creator: Osoba, která uploadovala přílohu
        :param str field: RTF pole uložení přílohy
        :param str atttype: Typ přílohy - z číselníku typů
        :param str attsubtype: Typ přílohy - z číselníku typů
        :param str container: Container unique identifier
        :param str document: Source document unique identifier
        :return: DocumentAttachment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_attachment_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.post_attachment_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def post_attachment_with_http_info(self, name, **kwargs):  # noqa: E501
        """uploaduje novou přílohu (Crud)  # noqa: E501

        Uploaduje novou souborovou přílohu dokumentu  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_attachment_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: Attachment name for display (required)
        :param Object body: binární soubor base64
        :param str storage: Replica ID storage application
        :param str title: Attachment title for display
        :param str creator: Osoba, která uploadovala přílohu
        :param str field: RTF pole uložení přílohy
        :param str atttype: Typ přílohy - z číselníku typů
        :param str attsubtype: Typ přílohy - z číselníku typů
        :param str container: Container unique identifier
        :param str document: Source document unique identifier
        :return: DocumentAttachment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'body', 'storage', 'title', 'creator', 'field', 'atttype', 'attsubtype', 'container', 'document']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_attachment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `post_attachment`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'storage' in params:
            query_params.append(('storage', params['storage']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'title' in params:
            query_params.append(('title', params['title']))  # noqa: E501
        if 'creator' in params:
            query_params.append(('creator', params['creator']))  # noqa: E501
        if 'field' in params:
            query_params.append(('field', params['field']))  # noqa: E501
        if 'atttype' in params:
            query_params.append(('atttype', params['atttype']))  # noqa: E501
        if 'attsubtype' in params:
            query_params.append(('attsubtype', params['attsubtype']))  # noqa: E501
        if 'container' in params:
            query_params.append(('container', params['container']))  # noqa: E501
        if 'document' in params:
            query_params.append(('document', params['document']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/attachment', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DocumentAttachment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_attachment(self, identifier, **kwargs):  # noqa: E501
        """aktualizuje metadata přílohy  # noqa: E501

        Aktualizuje metadata dokumentové přílohy v úložišti  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_attachment(identifier, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str identifier: Identifikátor uuid přílohy (required)
        :param DocumentAttachment body: DocumentAttachment object
        :param str storage: Replica ID storage application
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude operace provedena
        :return: DocumentAttachment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_attachment_with_http_info(identifier, **kwargs)  # noqa: E501
        else:
            (data) = self.put_attachment_with_http_info(identifier, **kwargs)  # noqa: E501
            return data

    def put_attachment_with_http_info(self, identifier, **kwargs):  # noqa: E501
        """aktualizuje metadata přílohy  # noqa: E501

        Aktualizuje metadata dokumentové přílohy v úložišti  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_attachment_with_http_info(identifier, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str identifier: Identifikátor uuid přílohy (required)
        :param DocumentAttachment body: DocumentAttachment object
        :param str storage: Replica ID storage application
        :param str author: Autorizace podle autora. Pokud je jméno mezi autory, bude operace provedena
        :return: DocumentAttachment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['identifier', 'body', 'storage', 'author']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_attachment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'identifier' is set
        if ('identifier' not in params or
                params['identifier'] is None):
            raise ValueError("Missing the required parameter `identifier` when calling `put_attachment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'identifier' in params:
            path_params['identifier'] = params['identifier']  # noqa: E501

        query_params = []
        if 'storage' in params:
            query_params.append(('storage', params['storage']))  # noqa: E501
        if 'author' in params:
            query_params.append(('author', params['author']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/attachment/{identifier}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DocumentAttachment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from esmlouvy_connector.models.address import Address
from esmlouvy_connector.models.base_domino_document import BaseDominoDocument
from esmlouvy_connector.models.base_sheet_document import BaseSheetDocument
from esmlouvy_connector.models.budget_category import BudgetCategory
from esmlouvy_connector.models.choice import Choice
from esmlouvy_connector.models.company import Company
from esmlouvy_connector.models.config_body import ConfigBody
from esmlouvy_connector.models.container import Container
from esmlouvy_connector.models.cover_sheet import CoverSheet
from esmlouvy_connector.models.document_acl import DocumentAcl
from esmlouvy_connector.models.document_attachment import DocumentAttachment
from esmlouvy_connector.models.document_attachment_entry import DocumentAttachmentEntry
from esmlouvy_connector.models.document_attachment_list import DocumentAttachmentList
from esmlouvy_connector.models.document_entry import DocumentEntry
from esmlouvy_connector.models.document_entry_list import DocumentEntryList
from esmlouvy_connector.models.document_header import DocumentHeader
from esmlouvy_connector.models.document_hidden import DocumentHidden
from esmlouvy_connector.models.document_workflow import DocumentWorkflow
from esmlouvy_connector.models.domino_commons import DominoCommons
from esmlouvy_connector.models.general_acl import GeneralAcl
from esmlouvy_connector.models.payment_event import PaymentEvent
from esmlouvy_connector.models.profile_directory import ProfileDirectory
from esmlouvy_connector.models.profile_main import ProfileMain
from esmlouvy_connector.models.profile_roles import ProfileRoles
from esmlouvy_connector.models.registration_sheet import RegistrationSheet
from esmlouvy_connector.models.replace_name import ReplaceName
from esmlouvy_connector.models.standpoint import Standpoint



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Company(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ico': 'str',
        'ico_exception': 'bool',
        'bank_account': 'str',
        'name': 'str',
        'representative': 'str',
        'vat_payer': 'bool',
        'address': 'Address'
    }

    attribute_map = {
        'ico': 'ico',
        'ico_exception': 'ico_exception',
        'bank_account': 'bank_account',
        'name': 'name',
        'representative': 'representative',
        'vat_payer': 'vat_payer',
        'address': 'address'
    }

    def __init__(self, ico=None, ico_exception=None, bank_account=None, name=None, representative=None, vat_payer=None, address=None):  # noqa: E501
        """Company - a model defined in Swagger"""  # noqa: E501
        self._ico = None
        self._ico_exception = None
        self._bank_account = None
        self._name = None
        self._representative = None
        self._vat_payer = None
        self._address = None
        self.discriminator = None
        if ico is not None:
            self.ico = ico
        if ico_exception is not None:
            self.ico_exception = ico_exception
        if bank_account is not None:
            self.bank_account = bank_account
        if name is not None:
            self.name = name
        if representative is not None:
            self.representative = representative
        if vat_payer is not None:
            self.vat_payer = vat_payer
        if address is not None:
            self.address = address

    @property
    def ico(self):
        """Gets the ico of this Company.  # noqa: E501

        contractor_ID - IČ/RČ  # noqa: E501

        :return: The ico of this Company.  # noqa: E501
        :rtype: str
        """
        return self._ico

    @ico.setter
    def ico(self, ico):
        """Sets the ico of this Company.

        contractor_ID - IČ/RČ  # noqa: E501

        :param ico: The ico of this Company.  # noqa: E501
        :type: str
        """

        self._ico = ico

    @property
    def ico_exception(self):
        """Gets the ico_exception of this Company.  # noqa: E501

        ID_exception - Výjimka ???  # noqa: E501

        :return: The ico_exception of this Company.  # noqa: E501
        :rtype: bool
        """
        return self._ico_exception

    @ico_exception.setter
    def ico_exception(self, ico_exception):
        """Sets the ico_exception of this Company.

        ID_exception - Výjimka ???  # noqa: E501

        :param ico_exception: The ico_exception of this Company.  # noqa: E501
        :type: bool
        """

        self._ico_exception = ico_exception

    @property
    def bank_account(self):
        """Gets the bank_account of this Company.  # noqa: E501

        contractor_bank_account - Číslo účtu  # noqa: E501

        :return: The bank_account of this Company.  # noqa: E501
        :rtype: str
        """
        return self._bank_account

    @bank_account.setter
    def bank_account(self, bank_account):
        """Sets the bank_account of this Company.

        contractor_bank_account - Číslo účtu  # noqa: E501

        :param bank_account: The bank_account of this Company.  # noqa: E501
        :type: str
        """

        self._bank_account = bank_account

    @property
    def name(self):
        """Gets the name of this Company.  # noqa: E501

        contractor_company - Obchodní název firmy  # noqa: E501

        :return: The name of this Company.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Company.

        contractor_company - Obchodní název firmy  # noqa: E501

        :param name: The name of this Company.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def representative(self):
        """Gets the representative of this Company.  # noqa: E501

        contractor_fullname - Statutarní orgán  # noqa: E501

        :return: The representative of this Company.  # noqa: E501
        :rtype: str
        """
        return self._representative

    @representative.setter
    def representative(self, representative):
        """Sets the representative of this Company.

        contractor_fullname - Statutarní orgán  # noqa: E501

        :param representative: The representative of this Company.  # noqa: E501
        :type: str
        """

        self._representative = representative

    @property
    def vat_payer(self):
        """Gets the vat_payer of this Company.  # noqa: E501

        contractor_VAT_payer - plátce DPH (původně NENÍ plátce DPH)  # noqa: E501

        :return: The vat_payer of this Company.  # noqa: E501
        :rtype: bool
        """
        return self._vat_payer

    @vat_payer.setter
    def vat_payer(self, vat_payer):
        """Sets the vat_payer of this Company.

        contractor_VAT_payer - plátce DPH (původně NENÍ plátce DPH)  # noqa: E501

        :param vat_payer: The vat_payer of this Company.  # noqa: E501
        :type: bool
        """

        self._vat_payer = vat_payer

    @property
    def address(self):
        """Gets the address of this Company.  # noqa: E501


        :return: The address of this Company.  # noqa: E501
        :rtype: Address
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this Company.


        :param address: The address of this Company.  # noqa: E501
        :type: Address
        """

        self._address = address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Company, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Company):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentAttachmentList(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key': 'str',
        'search': 'str',
        'category': 'str',
        'storage': 'str',
        'container_id': 'str',
        'document_id': 'str',
        'start': 'int',
        'page_size': 'int',
        'page': 'int',
        'count': 'int',
        'entries': 'list[DocumentAttachmentEntry]'
    }

    attribute_map = {
        'key': 'key',
        'search': 'search',
        'category': 'category',
        'storage': 'storage',
        'container_id': 'container_id',
        'document_id': 'document_id',
        'start': 'start',
        'page_size': 'page_size',
        'page': 'page',
        'count': 'count',
        'entries': 'entries'
    }

    def __init__(self, key=None, search=None, category=None, storage=None, container_id=None, document_id=None, start=None, page_size=None, page=None, count=None, entries=None):  # noqa: E501
        """DocumentAttachmentList - a model defined in Swagger"""  # noqa: E501
        self._key = None
        self._search = None
        self._category = None
        self._storage = None
        self._container_id = None
        self._document_id = None
        self._start = None
        self._page_size = None
        self._page = None
        self._count = None
        self._entries = None
        self.discriminator = None
        if key is not None:
            self.key = key
        if search is not None:
            self.search = search
        if category is not None:
            self.category = category
        if storage is not None:
            self.storage = storage
        if container_id is not None:
            self.container_id = container_id
        if document_id is not None:
            self.document_id = document_id
        if start is not None:
            self.start = start
        if page_size is not None:
            self.page_size = page_size
        if page is not None:
            self.page = page
        if count is not None:
            self.count = count
        if entries is not None:
            self.entries = entries

    @property
    def key(self):
        """Gets the key of this DocumentAttachmentList.  # noqa: E501

        Může být identifikátor nebo jiný textový klíč (např. čj.)  # noqa: E501

        :return: The key of this DocumentAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this DocumentAttachmentList.

        Může být identifikátor nebo jiný textový klíč (např. čj.)  # noqa: E501

        :param key: The key of this DocumentAttachmentList.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def search(self):
        """Gets the search of this DocumentAttachmentList.  # noqa: E501

        Text pro fulltextové vyhledávání  # noqa: E501

        :return: The search of this DocumentAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._search

    @search.setter
    def search(self, search):
        """Sets the search of this DocumentAttachmentList.

        Text pro fulltextové vyhledávání  # noqa: E501

        :param search: The search of this DocumentAttachmentList.  # noqa: E501
        :type: str
        """

        self._search = search

    @property
    def category(self):
        """Gets the category of this DocumentAttachmentList.  # noqa: E501

        Vrácená kategorie  # noqa: E501

        :return: The category of this DocumentAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this DocumentAttachmentList.

        Vrácená kategorie  # noqa: E501

        :param category: The category of this DocumentAttachmentList.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def storage(self):
        """Gets the storage of this DocumentAttachmentList.  # noqa: E501

        Replica ID storage application  # noqa: E501

        :return: The storage of this DocumentAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._storage

    @storage.setter
    def storage(self, storage):
        """Sets the storage of this DocumentAttachmentList.

        Replica ID storage application  # noqa: E501

        :param storage: The storage of this DocumentAttachmentList.  # noqa: E501
        :type: str
        """

        self._storage = storage

    @property
    def container_id(self):
        """Gets the container_id of this DocumentAttachmentList.  # noqa: E501

        Identifikátor kontejneru  # noqa: E501

        :return: The container_id of this DocumentAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this DocumentAttachmentList.

        Identifikátor kontejneru  # noqa: E501

        :param container_id: The container_id of this DocumentAttachmentList.  # noqa: E501
        :type: str
        """

        self._container_id = container_id

    @property
    def document_id(self):
        """Gets the document_id of this DocumentAttachmentList.  # noqa: E501

        UUID identifikátor rodičovského dokumentu  # noqa: E501

        :return: The document_id of this DocumentAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this DocumentAttachmentList.

        UUID identifikátor rodičovského dokumentu  # noqa: E501

        :param document_id: The document_id of this DocumentAttachmentList.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def start(self):
        """Gets the start of this DocumentAttachmentList.  # noqa: E501

        Počáteční dokument na stránce  # noqa: E501

        :return: The start of this DocumentAttachmentList.  # noqa: E501
        :rtype: int
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this DocumentAttachmentList.

        Počáteční dokument na stránce  # noqa: E501

        :param start: The start of this DocumentAttachmentList.  # noqa: E501
        :type: int
        """

        self._start = start

    @property
    def page_size(self):
        """Gets the page_size of this DocumentAttachmentList.  # noqa: E501

        Velikost stránky  # noqa: E501

        :return: The page_size of this DocumentAttachmentList.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this DocumentAttachmentList.

        Velikost stránky  # noqa: E501

        :param page_size: The page_size of this DocumentAttachmentList.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def page(self):
        """Gets the page of this DocumentAttachmentList.  # noqa: E501

        Požadovaná stránka  # noqa: E501

        :return: The page of this DocumentAttachmentList.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this DocumentAttachmentList.

        Požadovaná stránka  # noqa: E501

        :param page: The page of this DocumentAttachmentList.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def count(self):
        """Gets the count of this DocumentAttachmentList.  # noqa: E501

        celkový počet vrácených položek  # noqa: E501

        :return: The count of this DocumentAttachmentList.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this DocumentAttachmentList.

        celkový počet vrácených položek  # noqa: E501

        :param count: The count of this DocumentAttachmentList.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def entries(self):
        """Gets the entries of this DocumentAttachmentList.  # noqa: E501


        :return: The entries of this DocumentAttachmentList.  # noqa: E501
        :rtype: list[DocumentAttachmentEntry]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """Sets the entries of this DocumentAttachmentList.


        :param entries: The entries of this DocumentAttachmentList.  # noqa: E501
        :type: list[DocumentAttachmentEntry]
        """

        self._entries = entries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentAttachmentList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentAttachmentList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentWorkflow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'date_authorized': 'datetime',
        'date_send_sdr': 'datetime',
        'date_send_po1': 'datetime',
        'date_send_po2': 'datetime',
        'date_send_rsfl': 'datetime',
        'date_send_consultant': 'datetime',
        'date_send_or': 'datetime',
        'date_send_or_ph': 'datetime',
        'date_send_orr': 'datetime',
        'date_sr': 'datetime',
        'date_sor': 'datetime',
        'date_sor_ph': 'datetime',
        'date_spo2': 'datetime',
        'date_sor2': 'datetime'
    }

    attribute_map = {
        'date_authorized': 'date_authorized',
        'date_send_sdr': 'date_send_sdr',
        'date_send_po1': 'date_send_po1',
        'date_send_po2': 'date_send_po2',
        'date_send_rsfl': 'date_send_rsfl',
        'date_send_consultant': 'date_send_consultant',
        'date_send_or': 'date_send_or',
        'date_send_or_ph': 'date_send_or_ph',
        'date_send_orr': 'date_send_orr',
        'date_sr': 'date_sr',
        'date_sor': 'date_sor',
        'date_sor_ph': 'date_sor_ph',
        'date_spo2': 'date_spo2',
        'date_sor2': 'date_sor2'
    }

    def __init__(self, date_authorized=None, date_send_sdr=None, date_send_po1=None, date_send_po2=None, date_send_rsfl=None, date_send_consultant=None, date_send_or=None, date_send_or_ph=None, date_send_orr=None, date_sr=None, date_sor=None, date_sor_ph=None, date_spo2=None, date_sor2=None):  # noqa: E501
        """DocumentWorkflow - a model defined in Swagger"""  # noqa: E501
        self._date_authorized = None
        self._date_send_sdr = None
        self._date_send_po1 = None
        self._date_send_po2 = None
        self._date_send_rsfl = None
        self._date_send_consultant = None
        self._date_send_or = None
        self._date_send_or_ph = None
        self._date_send_orr = None
        self._date_sr = None
        self._date_sor = None
        self._date_sor_ph = None
        self._date_spo2 = None
        self._date_sor2 = None
        self.discriminator = None
        if date_authorized is not None:
            self.date_authorized = date_authorized
        if date_send_sdr is not None:
            self.date_send_sdr = date_send_sdr
        if date_send_po1 is not None:
            self.date_send_po1 = date_send_po1
        if date_send_po2 is not None:
            self.date_send_po2 = date_send_po2
        if date_send_rsfl is not None:
            self.date_send_rsfl = date_send_rsfl
        if date_send_consultant is not None:
            self.date_send_consultant = date_send_consultant
        if date_send_or is not None:
            self.date_send_or = date_send_or
        if date_send_or_ph is not None:
            self.date_send_or_ph = date_send_or_ph
        if date_send_orr is not None:
            self.date_send_orr = date_send_orr
        if date_sr is not None:
            self.date_sr = date_sr
        if date_sor is not None:
            self.date_sor = date_sor
        if date_sor_ph is not None:
            self.date_sor_ph = date_sor_ph
        if date_spo2 is not None:
            self.date_spo2 = date_spo2
        if date_sor2 is not None:
            self.date_sor2 = date_sor2

    @property
    def date_authorized(self):
        """Gets the date_authorized of this DocumentWorkflow.  # noqa: E501

        date_authorized - datum autorizace (zpracovatel)  # noqa: E501

        :return: The date_authorized of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_authorized

    @date_authorized.setter
    def date_authorized(self, date_authorized):
        """Sets the date_authorized of this DocumentWorkflow.

        date_authorized - datum autorizace (zpracovatel)  # noqa: E501

        :param date_authorized: The date_authorized of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_authorized = date_authorized

    @property
    def date_send_sdr(self):
        """Gets the date_send_sdr of this DocumentWorkflow.  # noqa: E501

        date_send_sdr  zasláno správci dílčího rozpočtu  # noqa: E501

        :return: The date_send_sdr of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_send_sdr

    @date_send_sdr.setter
    def date_send_sdr(self, date_send_sdr):
        """Sets the date_send_sdr of this DocumentWorkflow.

        date_send_sdr  zasláno správci dílčího rozpočtu  # noqa: E501

        :param date_send_sdr: The date_send_sdr of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_send_sdr = date_send_sdr

    @property
    def date_send_po1(self):
        """Gets the date_send_po1 of this DocumentWorkflow.  # noqa: E501

        date_send_po1  zasláno příkazci operace  # noqa: E501

        :return: The date_send_po1 of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_send_po1

    @date_send_po1.setter
    def date_send_po1(self, date_send_po1):
        """Sets the date_send_po1 of this DocumentWorkflow.

        date_send_po1  zasláno příkazci operace  # noqa: E501

        :param date_send_po1: The date_send_po1 of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_send_po1 = date_send_po1

    @property
    def date_send_po2(self):
        """Gets the date_send_po2 of this DocumentWorkflow.  # noqa: E501

        date_send_po2  zasláno příkazci operace - náměstek  # noqa: E501

        :return: The date_send_po2 of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_send_po2

    @date_send_po2.setter
    def date_send_po2(self, date_send_po2):
        """Sets the date_send_po2 of this DocumentWorkflow.

        date_send_po2  zasláno příkazci operace - náměstek  # noqa: E501

        :param date_send_po2: The date_send_po2 of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_send_po2 = date_send_po2

    @property
    def date_send_rsfl(self):
        """Gets the date_send_rsfl of this DocumentWorkflow.  # noqa: E501

        date_send_rsfl  zasláno náměstkovi - ŘSFL  # noqa: E501

        :return: The date_send_rsfl of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_send_rsfl

    @date_send_rsfl.setter
    def date_send_rsfl(self, date_send_rsfl):
        """Sets the date_send_rsfl of this DocumentWorkflow.

        date_send_rsfl  zasláno náměstkovi - ŘSFL  # noqa: E501

        :param date_send_rsfl: The date_send_rsfl of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_send_rsfl = date_send_rsfl

    @property
    def date_send_consultant(self):
        """Gets the date_send_consultant of this DocumentWorkflow.  # noqa: E501

        date_send_consultant  zasláno poradci náměstka - ŘSFL  # noqa: E501

        :return: The date_send_consultant of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_send_consultant

    @date_send_consultant.setter
    def date_send_consultant(self, date_send_consultant):
        """Sets the date_send_consultant of this DocumentWorkflow.

        date_send_consultant  zasláno poradci náměstka - ŘSFL  # noqa: E501

        :param date_send_consultant: The date_send_consultant of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_send_consultant = date_send_consultant

    @property
    def date_send_or(self):
        """Gets the date_send_or of this DocumentWorkflow.  # noqa: E501

        date_send_or  zasláno odboru rozpočtu  # noqa: E501

        :return: The date_send_or of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_send_or

    @date_send_or.setter
    def date_send_or(self, date_send_or):
        """Sets the date_send_or of this DocumentWorkflow.

        date_send_or  zasláno odboru rozpočtu  # noqa: E501

        :param date_send_or: The date_send_or of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_send_or = date_send_or

    @property
    def date_send_or_ph(self):
        """Gets the date_send_or_ph of this DocumentWorkflow.  # noqa: E501

        date_send_or_ph  přiděleno právníkovi  # noqa: E501

        :return: The date_send_or_ph of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_send_or_ph

    @date_send_or_ph.setter
    def date_send_or_ph(self, date_send_or_ph):
        """Sets the date_send_or_ph of this DocumentWorkflow.

        date_send_or_ph  přiděleno právníkovi  # noqa: E501

        :param date_send_or_ph: The date_send_or_ph of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_send_or_ph = date_send_or_ph

    @property
    def date_send_orr(self):
        """Gets the date_send_orr of this DocumentWorkflow.  # noqa: E501

        date_send_orr  příděleno rozpočtáři  # noqa: E501

        :return: The date_send_orr of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_send_orr

    @date_send_orr.setter
    def date_send_orr(self, date_send_orr):
        """Sets the date_send_orr of this DocumentWorkflow.

        date_send_orr  příděleno rozpočtáři  # noqa: E501

        :param date_send_orr: The date_send_orr of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_send_orr = date_send_orr

    @property
    def date_sr(self):
        """Gets the date_sr of this DocumentWorkflow.  # noqa: E501

        date_sr  stanovisko rozpočtáře  # noqa: E501

        :return: The date_sr of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_sr

    @date_sr.setter
    def date_sr(self, date_sr):
        """Sets the date_sr of this DocumentWorkflow.

        date_sr  stanovisko rozpočtáře  # noqa: E501

        :param date_sr: The date_sr of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_sr = date_sr

    @property
    def date_sor(self):
        """Gets the date_sor of this DocumentWorkflow.  # noqa: E501

        date_sor  stanovisko OR (managers)  # noqa: E501

        :return: The date_sor of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_sor

    @date_sor.setter
    def date_sor(self, date_sor):
        """Sets the date_sor of this DocumentWorkflow.

        date_sor  stanovisko OR (managers)  # noqa: E501

        :param date_sor: The date_sor of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_sor = date_sor

    @property
    def date_sor_ph(self):
        """Gets the date_sor_ph of this DocumentWorkflow.  # noqa: E501

        date_sor_ph  přiděleno právníkovi  ??? jak se liší od date_send_or_ph  # noqa: E501

        :return: The date_sor_ph of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_sor_ph

    @date_sor_ph.setter
    def date_sor_ph(self, date_sor_ph):
        """Sets the date_sor_ph of this DocumentWorkflow.

        date_sor_ph  přiděleno právníkovi  ??? jak se liší od date_send_or_ph  # noqa: E501

        :param date_sor_ph: The date_sor_ph of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_sor_ph = date_sor_ph

    @property
    def date_spo2(self):
        """Gets the date_spo2 of this DocumentWorkflow.  # noqa: E501

        date_spo2  stanovisko příkazce operace2  # noqa: E501

        :return: The date_spo2 of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_spo2

    @date_spo2.setter
    def date_spo2(self, date_spo2):
        """Sets the date_spo2 of this DocumentWorkflow.

        date_spo2  stanovisko příkazce operace2  # noqa: E501

        :param date_spo2: The date_spo2 of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_spo2 = date_spo2

    @property
    def date_sor2(self):
        """Gets the date_sor2 of this DocumentWorkflow.  # noqa: E501

        date_sor2  stanovisko odboru rozpočtu 2  # noqa: E501

        :return: The date_sor2 of this DocumentWorkflow.  # noqa: E501
        :rtype: datetime
        """
        return self._date_sor2

    @date_sor2.setter
    def date_sor2(self, date_sor2):
        """Sets the date_sor2 of this DocumentWorkflow.

        date_sor2  stanovisko odboru rozpočtu 2  # noqa: E501

        :param date_sor2: The date_sor2 of this DocumentWorkflow.  # noqa: E501
        :type: datetime
        """

        self._date_sor2 = date_sor2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentWorkflow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentWorkflow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BaseSheetDocument(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document': 'BaseDominoDocument',
        'container_id': 'str',
        'confirmed_id': 'bool',
        'workflow': 'DocumentWorkflow',
        'urgent': 'bool',
        'subject': 'str',
        'subject_mime': 'str',
        'subject_short': 'str',
        'comment': 'str',
        'attachments': 'list[DocumentAttachment]',
        'log': 'list[str]',
        'log_calendar': 'list[str]'
    }

    attribute_map = {
        'document': 'document',
        'container_id': 'container_id',
        'confirmed_id': 'confirmed_id',
        'workflow': 'workflow',
        'urgent': 'urgent',
        'subject': 'subject',
        'subject_mime': 'subject_mime',
        'subject_short': 'subject_short',
        'comment': 'comment',
        'attachments': 'attachments',
        'log': 'log',
        'log_calendar': 'log_calendar'
    }

    def __init__(self, document=None, container_id=None, confirmed_id=None, workflow=None, urgent=None, subject=None, subject_mime=None, subject_short=None, comment=None, attachments=None, log=None, log_calendar=None):  # noqa: E501
        """BaseSheetDocument - a model defined in Swagger"""  # noqa: E501
        self._document = None
        self._container_id = None
        self._confirmed_id = None
        self._workflow = None
        self._urgent = None
        self._subject = None
        self._subject_mime = None
        self._subject_short = None
        self._comment = None
        self._attachments = None
        self._log = None
        self._log_calendar = None
        self.discriminator = None
        if document is not None:
            self.document = document
        if container_id is not None:
            self.container_id = container_id
        if confirmed_id is not None:
            self.confirmed_id = confirmed_id
        if workflow is not None:
            self.workflow = workflow
        if urgent is not None:
            self.urgent = urgent
        if subject is not None:
            self.subject = subject
        if subject_mime is not None:
            self.subject_mime = subject_mime
        if subject_short is not None:
            self.subject_short = subject_short
        if comment is not None:
            self.comment = comment
        if attachments is not None:
            self.attachments = attachments
        if log is not None:
            self.log = log
        if log_calendar is not None:
            self.log_calendar = log_calendar

    @property
    def document(self):
        """Gets the document of this BaseSheetDocument.  # noqa: E501


        :return: The document of this BaseSheetDocument.  # noqa: E501
        :rtype: BaseDominoDocument
        """
        return self._document

    @document.setter
    def document(self, document):
        """Sets the document of this BaseSheetDocument.


        :param document: The document of this BaseSheetDocument.  # noqa: E501
        :type: BaseDominoDocument
        """

        self._document = document

    @property
    def container_id(self):
        """Gets the container_id of this BaseSheetDocument.  # noqa: E501

        UUID kontejneru, kam dokument patří  # noqa: E501

        :return: The container_id of this BaseSheetDocument.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this BaseSheetDocument.

        UUID kontejneru, kam dokument patří  # noqa: E501

        :param container_id: The container_id of this BaseSheetDocument.  # noqa: E501
        :type: str
        """

        self._container_id = container_id

    @property
    def confirmed_id(self):
        """Gets the confirmed_id of this BaseSheetDocument.  # noqa: E501

        Vytvořeno agentem importu daz z CSV  # noqa: E501

        :return: The confirmed_id of this BaseSheetDocument.  # noqa: E501
        :rtype: bool
        """
        return self._confirmed_id

    @confirmed_id.setter
    def confirmed_id(self, confirmed_id):
        """Sets the confirmed_id of this BaseSheetDocument.

        Vytvořeno agentem importu daz z CSV  # noqa: E501

        :param confirmed_id: The confirmed_id of this BaseSheetDocument.  # noqa: E501
        :type: bool
        """

        self._confirmed_id = confirmed_id

    @property
    def workflow(self):
        """Gets the workflow of this BaseSheetDocument.  # noqa: E501


        :return: The workflow of this BaseSheetDocument.  # noqa: E501
        :rtype: DocumentWorkflow
        """
        return self._workflow

    @workflow.setter
    def workflow(self, workflow):
        """Sets the workflow of this BaseSheetDocument.


        :param workflow: The workflow of this BaseSheetDocument.  # noqa: E501
        :type: DocumentWorkflow
        """

        self._workflow = workflow

    @property
    def urgent(self):
        """Gets the urgent of this BaseSheetDocument.  # noqa: E501

        Urgentní zakázka  # noqa: E501

        :return: The urgent of this BaseSheetDocument.  # noqa: E501
        :rtype: bool
        """
        return self._urgent

    @urgent.setter
    def urgent(self, urgent):
        """Sets the urgent of this BaseSheetDocument.

        Urgentní zakázka  # noqa: E501

        :param urgent: The urgent of this BaseSheetDocument.  # noqa: E501
        :type: bool
        """

        self._urgent = urgent

    @property
    def subject(self):
        """Gets the subject of this BaseSheetDocument.  # noqa: E501

        Předmět budoucí zakázky včetně zdůvodnění smlouvy  # noqa: E501

        :return: The subject of this BaseSheetDocument.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this BaseSheetDocument.

        Předmět budoucí zakázky včetně zdůvodnění smlouvy  # noqa: E501

        :param subject: The subject of this BaseSheetDocument.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def subject_mime(self):
        """Gets the subject_mime of this BaseSheetDocument.  # noqa: E501

        subject_rtf - Předmět budoucí zakázky včetně zdůvodnění smlouvy (MIME multipart).  Nepoužívat pro upload. Jen kvůli zpětné kompatibilitě. |   # noqa: E501

        :return: The subject_mime of this BaseSheetDocument.  # noqa: E501
        :rtype: str
        """
        return self._subject_mime

    @subject_mime.setter
    def subject_mime(self, subject_mime):
        """Sets the subject_mime of this BaseSheetDocument.

        subject_rtf - Předmět budoucí zakázky včetně zdůvodnění smlouvy (MIME multipart).  Nepoužívat pro upload. Jen kvůli zpětné kompatibilitě. |   # noqa: E501

        :param subject_mime: The subject_mime of this BaseSheetDocument.  # noqa: E501
        :type: str
        """

        self._subject_mime = subject_mime

    @property
    def subject_short(self):
        """Gets the subject_short of this BaseSheetDocument.  # noqa: E501

        Předmět budoucí zakázky velmi stručně pro zápis do účetního systému (150 znaků) |   # noqa: E501

        :return: The subject_short of this BaseSheetDocument.  # noqa: E501
        :rtype: str
        """
        return self._subject_short

    @subject_short.setter
    def subject_short(self, subject_short):
        """Sets the subject_short of this BaseSheetDocument.

        Předmět budoucí zakázky velmi stručně pro zápis do účetního systému (150 znaků) |   # noqa: E501

        :param subject_short: The subject_short of this BaseSheetDocument.  # noqa: E501
        :type: str
        """

        self._subject_short = subject_short

    @property
    def comment(self):
        """Gets the comment of this BaseSheetDocument.  # noqa: E501

        Poznmka odboru rozpočtu  # noqa: E501

        :return: The comment of this BaseSheetDocument.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this BaseSheetDocument.

        Poznmka odboru rozpočtu  # noqa: E501

        :param comment: The comment of this BaseSheetDocument.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def attachments(self):
        """Gets the attachments of this BaseSheetDocument.  # noqa: E501

        Souborové přílohy  # noqa: E501

        :return: The attachments of this BaseSheetDocument.  # noqa: E501
        :rtype: list[DocumentAttachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this BaseSheetDocument.

        Souborové přílohy  # noqa: E501

        :param attachments: The attachments of this BaseSheetDocument.  # noqa: E501
        :type: list[DocumentAttachment]
        """

        self._attachments = attachments

    @property
    def log(self):
        """Gets the log of this BaseSheetDocument.  # noqa: E501

        Procesní logy k dokumentu  # noqa: E501

        :return: The log of this BaseSheetDocument.  # noqa: E501
        :rtype: list[str]
        """
        return self._log

    @log.setter
    def log(self, log):
        """Sets the log of this BaseSheetDocument.

        Procesní logy k dokumentu  # noqa: E501

        :param log: The log of this BaseSheetDocument.  # noqa: E501
        :type: list[str]
        """

        self._log = log

    @property
    def log_calendar(self):
        """Gets the log_calendar of this BaseSheetDocument.  # noqa: E501

        Procesní logy k platebnímu kalendáři  # noqa: E501

        :return: The log_calendar of this BaseSheetDocument.  # noqa: E501
        :rtype: list[str]
        """
        return self._log_calendar

    @log_calendar.setter
    def log_calendar(self, log_calendar):
        """Sets the log_calendar of this BaseSheetDocument.

        Procesní logy k platebnímu kalendáři  # noqa: E501

        :param log_calendar: The log_calendar of this BaseSheetDocument.  # noqa: E501
        :type: list[str]
        """

        self._log_calendar = log_calendar

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BaseSheetDocument, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BaseSheetDocument):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Standpoint(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'domino': 'DominoCommons',
        'container_id': 'str',
        'parent_id': 'str',
        'parent_uuid': 'str',
        'type': 'str',
        'doc_type': 'str',
        'hide': 'str',
        'authorized': 'bool',
        'insyco': 'str',
        'draft': 'str',
        'check': 'list[str]',
        'parent_notified': 'bool',
        'status': 'str',
        'identifier': 'str',
        'identifier_contract': 'str',
        'identifier_global': 'str',
        'identifier_local': 'str',
        'creator_fullname': 'str',
        'creator_responsible': 'str',
        'reservation_number': 'str',
        'identifier_project': 'str',
        'stand': 'str',
        'note_stand': 'str',
        'attachments': 'list[DocumentAttachment]',
        'identifier_contract_new': 'str',
        'attachments_draft_contract': 'list[DocumentAttachment]',
        'stand_author': 'str',
        'stand_signature': 'str',
        'stand_date': 'date'
    }

    attribute_map = {
        'domino': 'domino',
        'container_id': 'container_id',
        'parent_id': 'parent_id',
        'parent_uuid': 'parent_uuid',
        'type': 'type',
        'doc_type': 'doc_type',
        'hide': 'hide',
        'authorized': 'authorized',
        'insyco': 'insyco',
        'draft': 'draft',
        'check': 'check',
        'parent_notified': 'parent_notified',
        'status': 'status',
        'identifier': 'identifier',
        'identifier_contract': 'identifier_contract',
        'identifier_global': 'identifier_global',
        'identifier_local': 'identifier_local',
        'creator_fullname': 'creator_fullname',
        'creator_responsible': 'creator_responsible',
        'reservation_number': 'reservation_number',
        'identifier_project': 'identifier_project',
        'stand': 'stand',
        'note_stand': 'note_stand',
        'attachments': 'attachments',
        'identifier_contract_new': 'identifier_contract_new',
        'attachments_draft_contract': 'attachments_draft_contract',
        'stand_author': 'stand_author',
        'stand_signature': 'stand_signature',
        'stand_date': 'stand_date'
    }

    def __init__(self, domino=None, container_id=None, parent_id=None, parent_uuid=None, type=None, doc_type=None, hide=None, authorized=None, insyco=None, draft=None, check=None, parent_notified=None, status=None, identifier=None, identifier_contract=None, identifier_global=None, identifier_local=None, creator_fullname=None, creator_responsible=None, reservation_number=None, identifier_project=None, stand=None, note_stand=None, attachments=None, identifier_contract_new=None, attachments_draft_contract=None, stand_author=None, stand_signature=None, stand_date=None):  # noqa: E501
        """Standpoint - a model defined in Swagger"""  # noqa: E501
        self._domino = None
        self._container_id = None
        self._parent_id = None
        self._parent_uuid = None
        self._type = None
        self._doc_type = None
        self._hide = None
        self._authorized = None
        self._insyco = None
        self._draft = None
        self._check = None
        self._parent_notified = None
        self._status = None
        self._identifier = None
        self._identifier_contract = None
        self._identifier_global = None
        self._identifier_local = None
        self._creator_fullname = None
        self._creator_responsible = None
        self._reservation_number = None
        self._identifier_project = None
        self._stand = None
        self._note_stand = None
        self._attachments = None
        self._identifier_contract_new = None
        self._attachments_draft_contract = None
        self._stand_author = None
        self._stand_signature = None
        self._stand_date = None
        self.discriminator = None
        if domino is not None:
            self.domino = domino
        if container_id is not None:
            self.container_id = container_id
        if parent_id is not None:
            self.parent_id = parent_id
        if parent_uuid is not None:
            self.parent_uuid = parent_uuid
        if type is not None:
            self.type = type
        if doc_type is not None:
            self.doc_type = doc_type
        if hide is not None:
            self.hide = hide
        if authorized is not None:
            self.authorized = authorized
        if insyco is not None:
            self.insyco = insyco
        if draft is not None:
            self.draft = draft
        if check is not None:
            self.check = check
        if parent_notified is not None:
            self.parent_notified = parent_notified
        if status is not None:
            self.status = status
        if identifier is not None:
            self.identifier = identifier
        if identifier_contract is not None:
            self.identifier_contract = identifier_contract
        if identifier_global is not None:
            self.identifier_global = identifier_global
        if identifier_local is not None:
            self.identifier_local = identifier_local
        if creator_fullname is not None:
            self.creator_fullname = creator_fullname
        if creator_responsible is not None:
            self.creator_responsible = creator_responsible
        if reservation_number is not None:
            self.reservation_number = reservation_number
        if identifier_project is not None:
            self.identifier_project = identifier_project
        if stand is not None:
            self.stand = stand
        if note_stand is not None:
            self.note_stand = note_stand
        if attachments is not None:
            self.attachments = attachments
        if identifier_contract_new is not None:
            self.identifier_contract_new = identifier_contract_new
        if attachments_draft_contract is not None:
            self.attachments_draft_contract = attachments_draft_contract
        if stand_author is not None:
            self.stand_author = stand_author
        if stand_signature is not None:
            self.stand_signature = stand_signature
        if stand_date is not None:
            self.stand_date = stand_date

    @property
    def domino(self):
        """Gets the domino of this Standpoint.  # noqa: E501


        :return: The domino of this Standpoint.  # noqa: E501
        :rtype: DominoCommons
        """
        return self._domino

    @domino.setter
    def domino(self, domino):
        """Sets the domino of this Standpoint.


        :param domino: The domino of this Standpoint.  # noqa: E501
        :type: DominoCommons
        """

        self._domino = domino

    @property
    def container_id(self):
        """Gets the container_id of this Standpoint.  # noqa: E501

        UUID kontejneru, kam dokument patří  # noqa: E501

        :return: The container_id of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this Standpoint.

        UUID kontejneru, kam dokument patří  # noqa: E501

        :param container_id: The container_id of this Standpoint.  # noqa: E501
        :type: str
        """

        self._container_id = container_id

    @property
    def parent_id(self):
        """Gets the parent_id of this Standpoint.  # noqa: E501

        UNID rodičovského dokument (evidenčního listu)  # noqa: E501

        :return: The parent_id of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this Standpoint.

        UNID rodičovského dokument (evidenčního listu)  # noqa: E501

        :param parent_id: The parent_id of this Standpoint.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def parent_uuid(self):
        """Gets the parent_uuid of this Standpoint.  # noqa: E501

        UUID identifikátor rodičovského dokumentu  # noqa: E501

        :return: The parent_uuid of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._parent_uuid

    @parent_uuid.setter
    def parent_uuid(self, parent_uuid):
        """Sets the parent_uuid of this Standpoint.

        UUID identifikátor rodičovského dokumentu  # noqa: E501

        :param parent_uuid: The parent_uuid of this Standpoint.  # noqa: E501
        :type: str
        """

        self._parent_uuid = parent_uuid

    @property
    def type(self):
        """Gets the type of this Standpoint.  # noqa: E501

        Typ stanoviska  # noqa: E501

        :return: The type of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Standpoint.

        Typ stanoviska  # noqa: E501

        :param type: The type of this Standpoint.  # noqa: E501
        :type: str
        """
        allowed_values = ["0", "1", "2.1", "2.2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def doc_type(self):
        """Gets the doc_type of this Standpoint.  # noqa: E501

        DocType - typ nadřízeného dokumentu  # noqa: E501

        :return: The doc_type of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._doc_type

    @doc_type.setter
    def doc_type(self, doc_type):
        """Sets the doc_type of this Standpoint.

        DocType - typ nadřízeného dokumentu  # noqa: E501

        :param doc_type: The doc_type of this Standpoint.  # noqa: E501
        :type: str
        """
        allowed_values = ["coverList", "evidenceList"]  # noqa: E501
        if doc_type not in allowed_values:
            raise ValueError(
                "Invalid value for `doc_type` ({0}), must be one of {1}"  # noqa: E501
                .format(doc_type, allowed_values)
            )

        self._doc_type = doc_type

    @property
    def hide(self):
        """Gets the hide of this Standpoint.  # noqa: E501

        Jakési pomocné pole ???  # noqa: E501

        :return: The hide of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._hide

    @hide.setter
    def hide(self, hide):
        """Sets the hide of this Standpoint.

        Jakési pomocné pole ???  # noqa: E501

        :param hide: The hide of this Standpoint.  # noqa: E501
        :type: str
        """

        self._hide = hide

    @property
    def authorized(self):
        """Gets the authorized of this Standpoint.  # noqa: E501

        Authorized - autorizační příznak ???  # noqa: E501

        :return: The authorized of this Standpoint.  # noqa: E501
        :rtype: bool
        """
        return self._authorized

    @authorized.setter
    def authorized(self, authorized):
        """Sets the authorized of this Standpoint.

        Authorized - autorizační příznak ???  # noqa: E501

        :param authorized: The authorized of this Standpoint.  # noqa: E501
        :type: bool
        """

        self._authorized = authorized

    @property
    def insyco(self):
        """Gets the insyco of this Standpoint.  # noqa: E501

        INSYCO - pravděpodobně něco historického ???  # noqa: E501

        :return: The insyco of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._insyco

    @insyco.setter
    def insyco(self, insyco):
        """Sets the insyco of this Standpoint.

        INSYCO - pravděpodobně něco historického ???  # noqa: E501

        :param insyco: The insyco of this Standpoint.  # noqa: E501
        :type: str
        """

        self._insyco = insyco

    @property
    def draft(self):
        """Gets the draft of this Standpoint.  # noqa: E501

        Něco historického ???  # noqa: E501

        :return: The draft of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._draft

    @draft.setter
    def draft(self, draft):
        """Sets the draft of this Standpoint.

        Něco historického ???  # noqa: E501

        :param draft: The draft of this Standpoint.  # noqa: E501
        :type: str
        """

        self._draft = draft

    @property
    def check(self):
        """Gets the check of this Standpoint.  # noqa: E501

        Vypočítávané pole v Dominu (jména), ale může být i jinak???  # noqa: E501

        :return: The check of this Standpoint.  # noqa: E501
        :rtype: list[str]
        """
        return self._check

    @check.setter
    def check(self, check):
        """Sets the check of this Standpoint.

        Vypočítávané pole v Dominu (jména), ale může být i jinak???  # noqa: E501

        :param check: The check of this Standpoint.  # noqa: E501
        :type: list[str]
        """

        self._check = check

    @property
    def parent_notified(self):
        """Gets the parent_notified of this Standpoint.  # noqa: E501

        isParentNotified = \"1\" pokud je v parent docu nastaven příznak ssdr=1  # noqa: E501

        :return: The parent_notified of this Standpoint.  # noqa: E501
        :rtype: bool
        """
        return self._parent_notified

    @parent_notified.setter
    def parent_notified(self, parent_notified):
        """Sets the parent_notified of this Standpoint.

        isParentNotified = \"1\" pokud je v parent docu nastaven příznak ssdr=1  # noqa: E501

        :param parent_notified: The parent_notified of this Standpoint.  # noqa: E501
        :type: bool
        """

        self._parent_notified = parent_notified

    @property
    def status(self):
        """Gets the status of this Standpoint.  # noqa: E501

        Stav nadřízeného dokumentu ???  # noqa: E501

        :return: The status of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Standpoint.

        Stav nadřízeného dokumentu ???  # noqa: E501

        :param status: The status of this Standpoint.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def identifier(self):
        """Gets the identifier of this Standpoint.  # noqa: E501

        Identifikační číslo listu  # noqa: E501

        :return: The identifier of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this Standpoint.

        Identifikační číslo listu  # noqa: E501

        :param identifier: The identifier of this Standpoint.  # noqa: E501
        :type: str
        """

        self._identifier = identifier

    @property
    def identifier_contract(self):
        """Gets the identifier_contract of this Standpoint.  # noqa: E501

        Evidenční číslo (je-li již známo)  # noqa: E501

        :return: The identifier_contract of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._identifier_contract

    @identifier_contract.setter
    def identifier_contract(self, identifier_contract):
        """Sets the identifier_contract of this Standpoint.

        Evidenční číslo (je-li již známo)  # noqa: E501

        :param identifier_contract: The identifier_contract of this Standpoint.  # noqa: E501
        :type: str
        """

        self._identifier_contract = identifier_contract

    @property
    def identifier_global(self):
        """Gets the identifier_global of this Standpoint.  # noqa: E501

        Číslo jednací MŽP  # noqa: E501

        :return: The identifier_global of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._identifier_global

    @identifier_global.setter
    def identifier_global(self, identifier_global):
        """Sets the identifier_global of this Standpoint.

        Číslo jednací MŽP  # noqa: E501

        :param identifier_global: The identifier_global of this Standpoint.  # noqa: E501
        :type: str
        """

        self._identifier_global = identifier_global

    @property
    def identifier_local(self):
        """Gets the identifier_local of this Standpoint.  # noqa: E501

        Odbor - číslo  # noqa: E501

        :return: The identifier_local of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._identifier_local

    @identifier_local.setter
    def identifier_local(self, identifier_local):
        """Sets the identifier_local of this Standpoint.

        Odbor - číslo  # noqa: E501

        :param identifier_local: The identifier_local of this Standpoint.  # noqa: E501
        :type: str
        """

        self._identifier_local = identifier_local

    @property
    def creator_fullname(self):
        """Gets the creator_fullname of this Standpoint.  # noqa: E501

        Zpracovatel (jména)  # noqa: E501

        :return: The creator_fullname of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._creator_fullname

    @creator_fullname.setter
    def creator_fullname(self, creator_fullname):
        """Sets the creator_fullname of this Standpoint.

        Zpracovatel (jména)  # noqa: E501

        :param creator_fullname: The creator_fullname of this Standpoint.  # noqa: E501
        :type: str
        """

        self._creator_fullname = creator_fullname

    @property
    def creator_responsible(self):
        """Gets the creator_responsible of this Standpoint.  # noqa: E501

        Příkazce operace (jména)  # noqa: E501

        :return: The creator_responsible of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._creator_responsible

    @creator_responsible.setter
    def creator_responsible(self, creator_responsible):
        """Sets the creator_responsible of this Standpoint.

        Příkazce operace (jména)  # noqa: E501

        :param creator_responsible: The creator_responsible of this Standpoint.  # noqa: E501
        :type: str
        """

        self._creator_responsible = creator_responsible

    @property
    def reservation_number(self):
        """Gets the reservation_number of this Standpoint.  # noqa: E501

        reservationNumber - Číslo rezervace  # noqa: E501

        :return: The reservation_number of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._reservation_number

    @reservation_number.setter
    def reservation_number(self, reservation_number):
        """Sets the reservation_number of this Standpoint.

        reservationNumber - Číslo rezervace  # noqa: E501

        :param reservation_number: The reservation_number of this Standpoint.  # noqa: E501
        :type: str
        """

        self._reservation_number = reservation_number

    @property
    def identifier_project(self):
        """Gets the identifier_project of this Standpoint.  # noqa: E501

        Vazba na programové financování - jde-li o ISPROFIN vyplnit číslo akce (13 znaků), nejde-li o ISPROFIN, nutno vyplnit číslo projektu (9 znaků)   # noqa: E501

        :return: The identifier_project of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._identifier_project

    @identifier_project.setter
    def identifier_project(self, identifier_project):
        """Sets the identifier_project of this Standpoint.

        Vazba na programové financování - jde-li o ISPROFIN vyplnit číslo akce (13 znaků), nejde-li o ISPROFIN, nutno vyplnit číslo projektu (9 znaků)   # noqa: E501

        :param identifier_project: The identifier_project of this Standpoint.  # noqa: E501
        :type: str
        """

        self._identifier_project = identifier_project

    @property
    def stand(self):
        """Gets the stand of this Standpoint.  # noqa: E501

        Mé stanovisko: Souhlasím s návrhem (1), Nesouhlasím, přepracovat (2), Definitivně zamítám návrh (0)   # noqa: E501

        :return: The stand of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._stand

    @stand.setter
    def stand(self, stand):
        """Sets the stand of this Standpoint.

        Mé stanovisko: Souhlasím s návrhem (1), Nesouhlasím, přepracovat (2), Definitivně zamítám návrh (0)   # noqa: E501

        :param stand: The stand of this Standpoint.  # noqa: E501
        :type: str
        """
        allowed_values = ["0", "1", "2"]  # noqa: E501
        if stand not in allowed_values:
            raise ValueError(
                "Invalid value for `stand` ({0}), must be one of {1}"  # noqa: E501
                .format(stand, allowed_values)
            )

        self._stand = stand

    @property
    def note_stand(self):
        """Gets the note_stand of this Standpoint.  # noqa: E501

        Poznámka ke stanovisku - RTF pole !!!  # noqa: E501

        :return: The note_stand of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._note_stand

    @note_stand.setter
    def note_stand(self, note_stand):
        """Sets the note_stand of this Standpoint.

        Poznámka ke stanovisku - RTF pole !!!  # noqa: E501

        :param note_stand: The note_stand of this Standpoint.  # noqa: E501
        :type: str
        """

        self._note_stand = note_stand

    @property
    def attachments(self):
        """Gets the attachments of this Standpoint.  # noqa: E501

        Souborové přílohy  # noqa: E501

        :return: The attachments of this Standpoint.  # noqa: E501
        :rtype: list[DocumentAttachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this Standpoint.

        Souborové přílohy  # noqa: E501

        :param attachments: The attachments of this Standpoint.  # noqa: E501
        :type: list[DocumentAttachment]
        """

        self._attachments = attachments

    @property
    def identifier_contract_new(self):
        """Gets the identifier_contract_new of this Standpoint.  # noqa: E501

        Číslo smlouvy  # noqa: E501

        :return: The identifier_contract_new of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._identifier_contract_new

    @identifier_contract_new.setter
    def identifier_contract_new(self, identifier_contract_new):
        """Sets the identifier_contract_new of this Standpoint.

        Číslo smlouvy  # noqa: E501

        :param identifier_contract_new: The identifier_contract_new of this Standpoint.  # noqa: E501
        :type: str
        """

        self._identifier_contract_new = identifier_contract_new

    @property
    def attachments_draft_contract(self):
        """Gets the attachments_draft_contract of this Standpoint.  # noqa: E501

        Attachments_Draft_Contract - Přílohy - návrh smlouvy nebo dodatku  # noqa: E501

        :return: The attachments_draft_contract of this Standpoint.  # noqa: E501
        :rtype: list[DocumentAttachment]
        """
        return self._attachments_draft_contract

    @attachments_draft_contract.setter
    def attachments_draft_contract(self, attachments_draft_contract):
        """Sets the attachments_draft_contract of this Standpoint.

        Attachments_Draft_Contract - Přílohy - návrh smlouvy nebo dodatku  # noqa: E501

        :param attachments_draft_contract: The attachments_draft_contract of this Standpoint.  # noqa: E501
        :type: list[DocumentAttachment]
        """

        self._attachments_draft_contract = attachments_draft_contract

    @property
    def stand_author(self):
        """Gets the stand_author of this Standpoint.  # noqa: E501

        Jméno autora  # noqa: E501

        :return: The stand_author of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._stand_author

    @stand_author.setter
    def stand_author(self, stand_author):
        """Sets the stand_author of this Standpoint.

        Jméno autora  # noqa: E501

        :param stand_author: The stand_author of this Standpoint.  # noqa: E501
        :type: str
        """

        self._stand_author = stand_author

    @property
    def stand_signature(self):
        """Gets the stand_signature of this Standpoint.  # noqa: E501

        Podpis autora  # noqa: E501

        :return: The stand_signature of this Standpoint.  # noqa: E501
        :rtype: str
        """
        return self._stand_signature

    @stand_signature.setter
    def stand_signature(self, stand_signature):
        """Sets the stand_signature of this Standpoint.

        Podpis autora  # noqa: E501

        :param stand_signature: The stand_signature of this Standpoint.  # noqa: E501
        :type: str
        """

        self._stand_signature = stand_signature

    @property
    def stand_date(self):
        """Gets the stand_date of this Standpoint.  # noqa: E501

        datum vydání  # noqa: E501

        :return: The stand_date of this Standpoint.  # noqa: E501
        :rtype: date
        """
        return self._stand_date

    @stand_date.setter
    def stand_date(self, stand_date):
        """Sets the stand_date of this Standpoint.

        datum vydání  # noqa: E501

        :param stand_date: The stand_date of this Standpoint.  # noqa: E501
        :type: date
        """

        self._stand_date = stand_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Standpoint, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Standpoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentHidden(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'doc_type': 'str',
        'old_contract': 'str',
        'unid': 'str',
        'vat': 'str',
        'contract_value_tax_el': 'str',
        'creator_delegated_names': 'list[str]',
        'cancelled': 'str',
        'cancelled_name': 'str',
        'cal_edit': 'str',
        'evidence_note_unid': 'str',
        'type_new': 'str',
        'or_check': 'str',
        'sub_contract': 'bool',
        'identifier_main_contract': 'str'
    }

    attribute_map = {
        'status': 'status',
        'doc_type': 'doc_type',
        'old_contract': 'old_contract',
        'unid': 'unid',
        'vat': 'vat',
        'contract_value_tax_el': 'contract_value_tax_el',
        'creator_delegated_names': 'creator_delegated_names',
        'cancelled': 'cancelled',
        'cancelled_name': 'cancelled_name',
        'cal_edit': 'cal_edit',
        'evidence_note_unid': 'evidence_note_unid',
        'type_new': 'type_new',
        'or_check': 'or_check',
        'sub_contract': 'sub_contract',
        'identifier_main_contract': 'identifier_main_contract'
    }

    def __init__(self, status=None, doc_type=None, old_contract=None, unid=None, vat=None, contract_value_tax_el=None, creator_delegated_names=None, cancelled=None, cancelled_name=None, cal_edit=None, evidence_note_unid=None, type_new=None, or_check=None, sub_contract=None, identifier_main_contract=None):  # noqa: E501
        """DocumentHidden - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._doc_type = None
        self._old_contract = None
        self._unid = None
        self._vat = None
        self._contract_value_tax_el = None
        self._creator_delegated_names = None
        self._cancelled = None
        self._cancelled_name = None
        self._cal_edit = None
        self._evidence_note_unid = None
        self._type_new = None
        self._or_check = None
        self._sub_contract = None
        self._identifier_main_contract = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if doc_type is not None:
            self.doc_type = doc_type
        if old_contract is not None:
            self.old_contract = old_contract
        if unid is not None:
            self.unid = unid
        if vat is not None:
            self.vat = vat
        if contract_value_tax_el is not None:
            self.contract_value_tax_el = contract_value_tax_el
        if creator_delegated_names is not None:
            self.creator_delegated_names = creator_delegated_names
        if cancelled is not None:
            self.cancelled = cancelled
        if cancelled_name is not None:
            self.cancelled_name = cancelled_name
        if cal_edit is not None:
            self.cal_edit = cal_edit
        if evidence_note_unid is not None:
            self.evidence_note_unid = evidence_note_unid
        if type_new is not None:
            self.type_new = type_new
        if or_check is not None:
            self.or_check = or_check
        if sub_contract is not None:
            self.sub_contract = sub_contract
        if identifier_main_contract is not None:
            self.identifier_main_contract = identifier_main_contract

    @property
    def status(self):
        """Gets the status of this DocumentHidden.  # noqa: E501

        status  # noqa: E501

        :return: The status of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DocumentHidden.

        status  # noqa: E501

        :param status: The status of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def doc_type(self):
        """Gets the doc_type of this DocumentHidden.  # noqa: E501

        DocType  # noqa: E501

        :return: The doc_type of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._doc_type

    @doc_type.setter
    def doc_type(self, doc_type):
        """Sets the doc_type of this DocumentHidden.

        DocType  # noqa: E501

        :param doc_type: The doc_type of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._doc_type = doc_type

    @property
    def old_contract(self):
        """Gets the old_contract of this DocumentHidden.  # noqa: E501

        OldContract  # noqa: E501

        :return: The old_contract of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._old_contract

    @old_contract.setter
    def old_contract(self, old_contract):
        """Sets the old_contract of this DocumentHidden.

        OldContract  # noqa: E501

        :param old_contract: The old_contract of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._old_contract = old_contract

    @property
    def unid(self):
        """Gets the unid of this DocumentHidden.  # noqa: E501

        unid  # noqa: E501

        :return: The unid of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._unid

    @unid.setter
    def unid(self, unid):
        """Sets the unid of this DocumentHidden.

        unid  # noqa: E501

        :param unid: The unid of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._unid = unid

    @property
    def vat(self):
        """Gets the vat of this DocumentHidden.  # noqa: E501

        VAT  # noqa: E501

        :return: The vat of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._vat

    @vat.setter
    def vat(self, vat):
        """Sets the vat of this DocumentHidden.

        VAT  # noqa: E501

        :param vat: The vat of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._vat = vat

    @property
    def contract_value_tax_el(self):
        """Gets the contract_value_tax_el of this DocumentHidden.  # noqa: E501

        contract_value_tax_EL  # noqa: E501

        :return: The contract_value_tax_el of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._contract_value_tax_el

    @contract_value_tax_el.setter
    def contract_value_tax_el(self, contract_value_tax_el):
        """Sets the contract_value_tax_el of this DocumentHidden.

        contract_value_tax_EL  # noqa: E501

        :param contract_value_tax_el: The contract_value_tax_el of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._contract_value_tax_el = contract_value_tax_el

    @property
    def creator_delegated_names(self):
        """Gets the creator_delegated_names of this DocumentHidden.  # noqa: E501

        creator_delegated - (jména)  # noqa: E501

        :return: The creator_delegated_names of this DocumentHidden.  # noqa: E501
        :rtype: list[str]
        """
        return self._creator_delegated_names

    @creator_delegated_names.setter
    def creator_delegated_names(self, creator_delegated_names):
        """Sets the creator_delegated_names of this DocumentHidden.

        creator_delegated - (jména)  # noqa: E501

        :param creator_delegated_names: The creator_delegated_names of this DocumentHidden.  # noqa: E501
        :type: list[str]
        """

        self._creator_delegated_names = creator_delegated_names

    @property
    def cancelled(self):
        """Gets the cancelled of this DocumentHidden.  # noqa: E501

        cancelled  (co se tam ukládá???)  # noqa: E501

        :return: The cancelled of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._cancelled

    @cancelled.setter
    def cancelled(self, cancelled):
        """Sets the cancelled of this DocumentHidden.

        cancelled  (co se tam ukládá???)  # noqa: E501

        :param cancelled: The cancelled of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._cancelled = cancelled

    @property
    def cancelled_name(self):
        """Gets the cancelled_name of this DocumentHidden.  # noqa: E501

        cancelledBy - (jméno)  # noqa: E501

        :return: The cancelled_name of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._cancelled_name

    @cancelled_name.setter
    def cancelled_name(self, cancelled_name):
        """Sets the cancelled_name of this DocumentHidden.

        cancelledBy - (jméno)  # noqa: E501

        :param cancelled_name: The cancelled_name of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._cancelled_name = cancelled_name

    @property
    def cal_edit(self):
        """Gets the cal_edit of this DocumentHidden.  # noqa: E501

        cal_edit  # noqa: E501

        :return: The cal_edit of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._cal_edit

    @cal_edit.setter
    def cal_edit(self, cal_edit):
        """Sets the cal_edit of this DocumentHidden.

        cal_edit  # noqa: E501

        :param cal_edit: The cal_edit of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._cal_edit = cal_edit

    @property
    def evidence_note_unid(self):
        """Gets the evidence_note_unid of this DocumentHidden.  # noqa: E501

        do tohoto pole se uloží unid evidenčního listu, ze kterého byl tento krycí vytvořen   # noqa: E501

        :return: The evidence_note_unid of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._evidence_note_unid

    @evidence_note_unid.setter
    def evidence_note_unid(self, evidence_note_unid):
        """Sets the evidence_note_unid of this DocumentHidden.

        do tohoto pole se uloží unid evidenčního listu, ze kterého byl tento krycí vytvořen   # noqa: E501

        :param evidence_note_unid: The evidence_note_unid of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._evidence_note_unid = evidence_note_unid

    @property
    def type_new(self):
        """Gets the type_new of this DocumentHidden.  # noqa: E501

        type_new  # noqa: E501

        :return: The type_new of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._type_new

    @type_new.setter
    def type_new(self, type_new):
        """Sets the type_new of this DocumentHidden.

        type_new  # noqa: E501

        :param type_new: The type_new of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._type_new = type_new

    @property
    def or_check(self):
        """Gets the or_check of this DocumentHidden.  # noqa: E501

        ORCheck  # noqa: E501

        :return: The or_check of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._or_check

    @or_check.setter
    def or_check(self, or_check):
        """Sets the or_check of this DocumentHidden.

        ORCheck  # noqa: E501

        :param or_check: The or_check of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._or_check = or_check

    @property
    def sub_contract(self):
        """Gets the sub_contract of this DocumentHidden.  # noqa: E501

        isSubContract - jde o dodatek?  # noqa: E501

        :return: The sub_contract of this DocumentHidden.  # noqa: E501
        :rtype: bool
        """
        return self._sub_contract

    @sub_contract.setter
    def sub_contract(self, sub_contract):
        """Sets the sub_contract of this DocumentHidden.

        isSubContract - jde o dodatek?  # noqa: E501

        :param sub_contract: The sub_contract of this DocumentHidden.  # noqa: E501
        :type: bool
        """

        self._sub_contract = sub_contract

    @property
    def identifier_main_contract(self):
        """Gets the identifier_main_contract of this DocumentHidden.  # noqa: E501

        identifier_MainContract - ev. cislo puvodni verze smlouvy   # noqa: E501

        :return: The identifier_main_contract of this DocumentHidden.  # noqa: E501
        :rtype: str
        """
        return self._identifier_main_contract

    @identifier_main_contract.setter
    def identifier_main_contract(self, identifier_main_contract):
        """Sets the identifier_main_contract of this DocumentHidden.

        identifier_MainContract - ev. cislo puvodni verze smlouvy   # noqa: E501

        :param identifier_main_contract: The identifier_main_contract of this DocumentHidden.  # noqa: E501
        :type: str
        """

        self._identifier_main_contract = identifier_main_contract

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentHidden, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentHidden):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
